# vs-dfft

Collection of Discrete/Fast Fourier Transform VapourSynth functions

## How to use

```py
from vsdfft import FFTSpectrum

src = ...

spectrum = FFTSpectrum(src)
```

You can install [CuPy](https://docs.cupy.dev/en/stable/install.html) if you have an nvidia GPU to have a 5x speedup.

## How to install

Install `vsdfft` with the following command:

```sh
pip install vsdfft
```

Or if you want the latest git version, install it with this command:

```sh
pip install git+https://github.com/Setsugennoao/vs-dfft.git
```

<br>
